@@ -25,7 +25,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.4.0"
+#define LIBGNUTLS_VERSION "0.4.1"
 
 #include <sys/types.h>
 #include <time.h>
@@ -56,10 +56,12 @@ typedef enum GNUTLS_AlertDescription { GNUTLS_A_CLOSE_NOTIFY, GNUTLS_A_UNEXPECTE
 			GNUTLS_A_NO_RENEGOTIATION=100
 } GNUTLS_AlertDescription;
 
+#define GNUTLS_CERT_EXPIRED 8
+
 typedef enum GNUTLS_CertificateStatus { 
 	GNUTLS_CERT_NOT_TRUSTED=2, 
 	GNUTLS_CERT_INVALID=4, 
-	GNUTLS_CERT_EXPIRED=8, GNUTLS_CERT_CORRUPTED=16,
+	GNUTLS_CERT_CORRUPTED=16,
 	GNUTLS_CERT_REVOKED=32
 } GNUTLS_CertificateStatus;
 
@@ -379,7 +381,7 @@ int gnutls_x509_extract_certificate_version( const gnutls_datum*);
 int gnutls_x509_extract_certificate_serial(const gnutls_datum * cert, char* result, int* result_size);
 time_t gnutls_x509_extract_certificate_activation_time( const gnutls_datum*);
 time_t gnutls_x509_extract_certificate_expiration_time( const gnutls_datum*);
-int gnutls_x509_extract_subject_alt_name( const gnutls_datum*, int seq, char*, int*);
+int gnutls_x509_extract_certificate_subject_alt_name( const gnutls_datum*, int seq, char*, int*);
 int gnutls_x509_pkcs7_extract_certificate(const gnutls_datum * pkcs7_struct, int indx, char* certificate, int* certificate_size);
 int gnutls_x509_extract_certificate_pk_algorithm( const gnutls_datum * cert, int* bits);
 
@@ -404,7 +406,10 @@ int gnutls_openpgp_verify_key( const gnutls_datum* keyring,
 
 /* get data from the state */
 const gnutls_datum* gnutls_certificate_get_peers( GNUTLS_STATE, int* list_size);
-const gnutls_datum *gnutls_certificate_get_ours(GNUTLS_STATE state);
+const gnutls_datum *gnutls_certificate_get_ours( GNUTLS_STATE state);
+
+time_t gnutls_certificate_activation_time_peers(GNUTLS_STATE state);
+time_t gnutls_certificate_expiration_time_peers(GNUTLS_STATE state);
 
 int gnutls_certificate_client_get_request_status(  GNUTLS_STATE);
 int gnutls_certificate_verify_peers( GNUTLS_STATE);
@@ -481,7 +486,6 @@ int gnutls_b64_decode_fmt( const gnutls_datum *b64_data, char* result, int* resu
 #define GNUTLS_E_DH_PRIME_UNACCEPTABLE -63
 #define GNUTLS_E_FILE_ERROR -64
 #define GNUTLS_E_ASCII_ARMOR_ERROR -65
-#define GNUTLS_E_UNIX_TIME_LIMIT_EXCEEDED -66
 #define GNUTLS_E_ASN1_ELEMENT_NOT_FOUND -67
 #define GNUTLS_E_ASN1_IDENTIFIER_NOT_FOUND -68
 #define GNUTLS_E_ASN1_DER_ERROR -69
