@@ -672,7 +672,7 @@ _asn1_ordering_set(unsigned char *der,node_asn *node)
 
   first=last=NULL;
   while(p){
-    p_vet=(struct vet *)gnutls_malloc( sizeof(struct vet));
+    p_vet=(struct vet *)gnutls_alloca( sizeof(struct vet));
     if (p_vet==NULL) return;
     
     p_vet->next=NULL;
@@ -702,13 +702,13 @@ _asn1_ordering_set(unsigned char *der,node_asn *node)
     while(p2_vet){
       if(p_vet->value>p2_vet->value){
 	/* change position */
-	temp=(unsigned char *)gnutls_malloc( p_vet->end-counter);
+	temp=(unsigned char *)gnutls_alloca( p_vet->end-counter);
 	if (temp==NULL) return;
 	
 	memcpy(temp,der+counter,p_vet->end-counter);
 	memmove(der+counter,der+p_vet->end,p2_vet->end-p_vet->end);
 	memcpy(der+p_vet->end,temp,p_vet->end-counter);
-	gnutls_free(temp);
+	gnutls_afree(temp);
 	
 	tag=p_vet->value;
 	p_vet->value=p2_vet->value;
@@ -724,7 +724,7 @@ _asn1_ordering_set(unsigned char *der,node_asn *node)
 
     if(p_vet!=first) p_vet->prev->next=NULL;
     else first=NULL;
-    gnutls_free(p_vet);
+    gnutls_afree(p_vet);
     p_vet=first;
   }
 }
@@ -756,7 +756,7 @@ _asn1_ordering_set_of(unsigned char *der,node_asn *node)
 
   first=last=NULL;
   while(p){
-    p_vet=(struct vet *)gnutls_malloc(sizeof(struct vet));
+    p_vet=(struct vet *)gnutls_alloca(sizeof(struct vet));
     if (p_vet==NULL) return;
     
     p_vet->next=NULL;
@@ -796,13 +796,13 @@ _asn1_ordering_set_of(unsigned char *der,node_asn *node)
 
       if(change==1){
 	/* change position */
-	temp=(unsigned char *)gnutls_malloc(p_vet->end-counter);
+	temp=(unsigned char *)gnutls_alloca(p_vet->end-counter);
 	if (temp==NULL) return;
 	
 	memcpy(temp,der+counter,p_vet->end-counter);
 	memmove(der+counter,der+p_vet->end,p2_vet->end-p_vet->end);
 	memcpy(der+p_vet->end,temp,p_vet->end-counter);
-	gnutls_free(temp);
+	gnutls_afree(temp);
 	
 	p_vet->end=counter+(p2_vet->end-p_vet->end);
       }
@@ -814,7 +814,7 @@ _asn1_ordering_set_of(unsigned char *der,node_asn *node)
 
     if(p_vet!=first) p_vet->prev->next=NULL;
     else first=NULL;
-    gnutls_free(p_vet);
+    gnutls_afree(p_vet);
     p_vet=first;
   }
 }
@@ -1177,12 +1177,12 @@ asn1_get_der(node_asn *root,unsigned char *der,int len)
 	tag=_asn1_get_tag_der(der+counter,&class,&len2);
 	len2+=_asn1_get_length_der(der+counter+len2,&len3);
 	_asn1_length_der(len2+len3,NULL,&len4);
-	temp2=(unsigned char *)gnutls_malloc(len2+len3+len4);
+	temp2=(unsigned char *)gnutls_alloca(len2+len3+len4);
         if (temp2==NULL) return ASN_MEM_ERROR;
         
 	_asn1_octet_der(der+counter,len2+len3,temp2,&len4);
 	_asn1_set_value(p,temp2,len4);
-	gnutls_free(temp2);
+	gnutls_afree(temp2);
 	counter+=len2+len3;
 	move=RIGHT;
 	break;
